@@ -11,7 +11,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List
+from typing import IO, Any, Dict, List, Union
 
 if sys.version_info >= (3, 8):
     from typing import Literal
@@ -735,18 +735,20 @@ ListTagsForResourceResponseTypeDef = TypedDict(
     "ListTagsForResourceResponseTypeDef", {"tags": List["TagTypeDef"]}, total=False
 )
 
-MessageTypeDef = TypedDict("MessageTypeDef", {"messageId": str, "payload": bytes})
+MessageTypeDef = TypedDict("MessageTypeDef", {"messageId": str, "payload": Union[bytes, IO[bytes]]})
 
 PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef", {"MaxItems": int, "PageSize": int, "StartingToken": str}, total=False
 )
 
 RunPipelineActivityResponseTypeDef = TypedDict(
-    "RunPipelineActivityResponseTypeDef", {"payloads": List[bytes], "logResult": str}, total=False
+    "RunPipelineActivityResponseTypeDef",
+    {"payloads": List[Union[bytes, IO[bytes]]], "logResult": str},
+    total=False,
 )
 
 SampleChannelDataResponseTypeDef = TypedDict(
-    "SampleChannelDataResponseTypeDef", {"payloads": List[bytes]}, total=False
+    "SampleChannelDataResponseTypeDef", {"payloads": List[Union[bytes, IO[bytes]]]}, total=False
 )
 
 StartPipelineReprocessingResponseTypeDef = TypedDict(
